CREATE TABLE account (login VARCHAR(100) NOT NULL UNIQUE, created TIMESTAMP NOT NULL, password VARCHAR(100), rfc2307_password VARCHAR(46), sha5_hex_password VARCHAR(128), strong_password VARCHAR(64), organisation_id INTEGER, person_id INTEGER, PRIMARY KEY (login))
CREATE TABLE organisation (organisation_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, base_dn VARCHAR(1000), CITY VARCHAR(100), COUNTRY VARCHAR(100), dialect_region VARCHAR(100), EMAIL VARCHAR(1000), FAX VARCHAR(100), NAME VARCHAR(100), NOTE VARCHAR(255), recording_equipment_nr INTEGER, STREET VARCHAR(100), TELEPHONE VARCHAR(100), transfer_rate_limit INTEGER, TYPE VARCHAR(100), URI VARCHAR(1000), wait_for_complete_upload SMALLINT DEFAULT 0, ZIPCODE VARCHAR(10), PRIMARY KEY (organisation_id))
CREATE TABLE import (description VARCHAR(100) NOT NULL, id VARCHAR(10) NOT NULL, type VARCHAR(100) NOT NULL, value VARCHAR(1000) NOT NULL, PRIMARY KEY (description, id, type, value))
CREATE TABLE person (person_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, DTYPE VARCHAR(31), address VARCHAR(1000), birth_place VARCHAR(100), CITY VARCHAR(100), code VARCHAR(10), comments VARCHAR(255), COUNTRY VARCHAR(100), date_of_birth DATE, EMAIL VARCHAR(1000), forename VARCHAR(100), name VARCHAR(100), profession VARCHAR(100), REGISTERED TIMESTAMP, sex VARCHAR(10), STREET VARCHAR(1000), UUID VARCHAR(36), ZIPCODE VARCHAR(100), PRIMARY KEY (person_id))
CREATE TABLE user_role (role_name VARCHAR(100) NOT NULL, login VARCHAR(100) NOT NULL, PRIMARY KEY (role_name, login))
CREATE TABLE public.audio_format (name VARCHAR(100) NOT NULL UNIQUE, bigendian SMALLINT DEFAULT 0, channels INTEGER, encoding VARCHAR(100), framesize INTEGER, quantisation INTEGER, samplerate FLOAT, PRIMARY KEY (name))
CREATE TABLE speaker (person_id INTEGER NOT NULL, accent VARCHAR(100), additional_language VARCHAR(100), brace SMALLINT DEFAULT 0, height FLOAT, mother_tongue VARCHAR(100), mother_tongue_father VARCHAR(100), mother_tongue_mother VARCHAR(100), mouth_piercing SMALLINT DEFAULT 0, MUSICALINSTRUMENT VARCHAR(255), smoker SMALLINT DEFAULT 0, type VARCHAR(8), weight FLOAT, dialect_region INTEGER, PRIMARY KEY (person_id))
CREATE TABLE public.info (info_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, deployment_date TIMESTAMP, DESCRIPTION VARCHAR(1000), NAME VARCHAR(100), update_from VARCHAR(100), VERSION VARCHAR(100), PRIMARY KEY (info_id))
CREATE TABLE public.project (name VARCHAR(100) NOT NULL UNIQUE, context_path VARCHAR(20), description VARCHAR(1000), hosts VARCHAR(255), session_code VARCHAR(100), show_stop_record_button SMALLINT DEFAULT 0, audioformat VARCHAR(100), session_finished_l_msg_id INTEGER, SPEAKERFORMCONFIGURATION_id INTEGER, PRIMARY KEY (name))
CREATE TABLE public.audio_device (audio_device_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, jextension VARCHAR(20), name VARCHAR(500), is_playback SMALLINT DEFAULT 0 NOT NULL, regex SMALLINT DEFAULT 0 NOT NULL, PRIMARY KEY (audio_device_id))
CREATE TABLE session (session_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, code VARCHAR(10), comment VARCHAR(1000), DATE TIMESTAMP, environment VARCHAR(100), jsessionid VARCHAR(100), status VARCHAR(10), storage_dir_url VARCHAR(1000), type VARCHAR(10), organisation_id INTEGER, project VARCHAR(100), script_id INTEGER, PRIMARY KEY (session_id))
CREATE TABLE public.dialect_region (dialect_region_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, ALTERNATIVE SMALLINT DEFAULT 0, country VARCHAR(1000), ISO_3166_2_CODE VARCHAR(6), name VARCHAR(1000), position INTEGER, state VARCHAR(1000), PRIMARY KEY (dialect_region_id))
CREATE TABLE recording (recording_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, DTYPE VARCHAR(31), position INTEGER, section_id INTEGER, PRESENTER BLOB(2147483647), group_id INTEGER, beep VARCHAR(10), BLOCKED SMALLINT DEFAULT 0, finalsilence INTEGER, itemcode VARCHAR(255), postrecdelay INTEGER, prerecdelay INTEGER, recduration INTEGER, rectype VARCHAR(10), reccomment_id INTEGER, recinstructions_id INTEGER, PRIMARY KEY (recording_id))
CREATE TABLE recgroup (recording_id INTEGER NOT NULL, group_id INTEGER NOT NULL UNIQUE, PRIMARY KEY (recording_id))
CREATE TABLE section (section_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, mode VARCHAR(100), name VARCHAR(100), ordering VARCHAR(100), promptphase VARCHAR(100), section_position INTEGER, speakerdisplay VARCHAR(10), TRAINING SMALLINT DEFAULT 0, script_id INTEGER, section_position INTEGER, PRIMARY KEY (section_id))
CREATE TABLE mediaitem (mediaitem_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, alt VARCHAR(255), ANNOTATIONTEMPLATE SMALLINT DEFAULT 0, author VARCHAR(100), autoplay SMALLINT DEFAULT 0, charset VARCHAR(100), COUNTRYISO3166CODE VARCHAR(255), DESCRIPTION VARCHAR(255), height INTEGER, LANGUAGEISO639CODE VARCHAR(255), mimetype VARCHAR(100), modal SMALLINT DEFAULT 0, SCOPE VARCHAR(20), src VARCHAR(255), mediaitem VARCHAR(255), volume INTEGER, width INTEGER, PRIMARY KEY (mediaitem_id))
CREATE TABLE script (script_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, DTYPE VARCHAR(31), description VARCHAR(100), name VARCHAR(10) NOT NULL, PRIMARY KEY (script_id))
CREATE TABLE message (message_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, comment VARCHAR(255), contents VARCHAR(10000), date_confirmed TIMESTAMP, date_read TIMESTAMP, date_sent TIMESTAMP, status VARCHAR(100), subject VARCHAR(1000), from_login VARCHAR(100), to_login VARCHAR(100), reply_of INTEGER, PRIMARY KEY (message_id))
CREATE TABLE recording_file (recording_file_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, bigendian SMALLINT DEFAULT 0, bytes BIGINT, channels INTEGER, date TIMESTAMP, encoding VARCHAR(100), format VARCHAR(100), frames BIGINT, max_level FLOAT, quantisation INTEGER, samplerate FLOAT, signal_file VARCHAR(1000), status VARCHAR(100), VERSION INTEGER, recording_id INTEGER, session_id INTEGER, signal_id INTEGER, PRIMARY KEY (recording_file_id))
CREATE TABLE recording_track (recording_track_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, channel_index INTEGER, snr_estimated FLOAT, max_level FLOAT, recording_file_id INTEGER, PRIMARY KEY (recording_track_id))
CREATE TABLE public.metadata (metadata_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, script_id INTEGER, PRIMARY KEY (metadata_id))
CREATE TABLE public.property (property_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, key VARCHAR(100), value VARCHAR(100), metadata_id INTEGER, PRIMARY KEY (property_id))
CREATE TABLE reccomment (reccomment_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, reccomment VARCHAR(1000), PRIMARY KEY (reccomment_id))
CREATE TABLE recinstructions (recinstructions_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, charset VARCHAR(100), mimetype VARCHAR(100), recinstructions VARCHAR(1000), PRIMARY KEY (recinstructions_id))
CREATE TABLE annotation (annotation_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, anno_begin TIMESTAMP, anno_end TIMESTAMP, anno_text VARCHAR(1000), anno_type VARCHAR(100), annotator VARCHAR(100), COMMENT VARCHAR(1000), PRIORITY INTEGER, project VARCHAR(100), prompt VARCHAR(1000), quality VARCHAR(100), segment_begin INTEGER, segment_end INTEGER, signal_url VARCHAR(1000), status VARCHAR(100), PRIMARY KEY (annotation_id))
CREATE TABLE technician (person_id INTEGER NOT NULL, mobile VARCHAR(100), PRIMARY KEY (person_id))
CREATE TABLE signal (signal_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, signal_data INTEGER, PRIMARY KEY (signal_id))
CREATE TABLE public.localized_message (localized_message_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, LANGUAGECODEISO639 VARCHAR(3), MESSAGE VARCHAR(10000), localizable_message_id INTEGER, PRIMARY KEY (localized_message_id))
CREATE TABLE public.localizable_message (localizable_message_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, DESCRIPTION VARCHAR(1000), PRIMARY KEY (localizable_message_id))
CREATE TABLE FORMCONFIGURATION (id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, DEFAULTREQUIRED SMALLINT DEFAULT 0, DESCRIPTION VARCHAR(1000), DISPLAYNAME VARCHAR(255), PROPERTYCLASSID VARCHAR(255), PRIMARY KEY (id))
CREATE TABLE PROPERTYCONFIGURATION (id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, PROPERTYCLASSID VARCHAR(255), PROPERTYNAME VARCHAR(255), REQUIRED SMALLINT DEFAULT 0, SHOW SMALLINT DEFAULT 0, TYPEDPROPERTYDESCRIPTOR BLOB(2147483647), FORMCONFIGURATION_id INTEGER, position INTEGER, PRIMARY KEY (id))
CREATE TABLE distribution (distribution_id INTEGER GENERATED BY DEFAULT AS IDENTITY NOT NULL UNIQUE, DESCRIPTION VARCHAR(10000), NAME VARCHAR(100), VERSION VARCHAR(20), PRIMARY KEY (distribution_id))
CREATE TABLE project_admin_account (admin_account VARCHAR(100) NOT NULL, project VARCHAR(100) NOT NULL, PRIMARY KEY (admin_account, project))
CREATE TABLE project_account (account VARCHAR(100) NOT NULL, project VARCHAR(100) NOT NULL, PRIMARY KEY (account, project))
CREATE TABLE belongs_to (organisation_id INTEGER NOT NULL, person_id INTEGER NOT NULL, PRIMARY KEY (organisation_id, person_id))
CREATE TABLE project_organisations (organisation INTEGER NOT NULL, project VARCHAR(100) NOT NULL, PRIMARY KEY (organisation, project))
CREATE TABLE participates (speaker_id INTEGER NOT NULL, session_id INTEGER NOT NULL, PRIMARY KEY (speaker_id, session_id))
CREATE TABLE project_audio_device (project VARCHAR(100) NOT NULL, audio_device_id INTEGER NOT NULL, audioDevices_ORDER INTEGER, PRIMARY KEY (project, audio_device_id))
CREATE TABLE project_dialect_region (project VARCHAR(100) NOT NULL, dialect_region INTEGER NOT NULL, PRIMARY KEY (project, dialect_region))
CREATE TABLE project_scripts (project VARCHAR(100) NOT NULL, script INTEGER NOT NULL, PRIMARY KEY (project, script))
CREATE TABLE recording_mediaitem (PromptItem_recording_id INTEGER NOT NULL, mediaitems_mediaitem_id INTEGER NOT NULL, PRIMARY KEY (PromptItem_recording_id, mediaitems_mediaitem_id))
CREATE TABLE mediaitem_recording (Mediaitem_mediaitem_id INTEGER NOT NULL, promptItemsSet_recording_id INTEGER NOT NULL, PRIMARY KEY (Mediaitem_mediaitem_id, promptItemsSet_recording_id))
CREATE TABLE annotates (recording_id INTEGER NOT NULL, annotation_id INTEGER NOT NULL, PRIMARY KEY (recording_id, annotation_id))
CREATE TABLE supervises (recording_id INTEGER NOT NULL, technician_id INTEGER NOT NULL, PRIMARY KEY (recording_id, technician_id))
CREATE TABLE distribution_recording_files (disribution_id INTEGER NOT NULL, recording_file_id INTEGER NOT NULL, recordingFiles_ORDER INTEGER, PRIMARY KEY (disribution_id, recording_file_id))
ALTER TABLE account ADD CONSTRAINT ccuntrganisationid FOREIGN KEY (organisation_id) REFERENCES organisation (organisation_id)
ALTER TABLE account ADD CONSTRAINT account_person_id FOREIGN KEY (person_id) REFERENCES person (person_id)
ALTER TABLE user_role ADD CONSTRAINT FK_user_role_login FOREIGN KEY (login) REFERENCES account (login)
ALTER TABLE speaker ADD CONSTRAINT speaker_person_id FOREIGN KEY (person_id) REFERENCES person (person_id)
ALTER TABLE speaker ADD CONSTRAINT spakerdalectregion FOREIGN KEY (dialect_region) REFERENCES public.dialect_region (dialect_region_id)
ALTER TABLE public.project ADD CONSTRAINT prjcsssnfnshdlmsgd FOREIGN KEY (session_finished_l_msg_id) REFERENCES public.localizable_message (localizable_message_id)
ALTER TABLE public.project ADD CONSTRAINT projectaudioformat FOREIGN KEY (audioformat) REFERENCES public.audio_format (name)
ALTER TABLE public.project ADD CONSTRAINT prjSPKRFRMCNFGRTNd FOREIGN KEY (SPEAKERFORMCONFIGURATION_id) REFERENCES FORMCONFIGURATION (id)
ALTER TABLE session ADD CONSTRAINT sssionrgnisationid FOREIGN KEY (organisation_id) REFERENCES organisation (organisation_id)
ALTER TABLE session ADD CONSTRAINT FK_session_project FOREIGN KEY (project) REFERENCES public.project (name)
ALTER TABLE session ADD CONSTRAINT session_script_id FOREIGN KEY (script_id) REFERENCES script (script_id)
ALTER TABLE recording ADD CONSTRAINT recording_group_id FOREIGN KEY (group_id) REFERENCES recgroup (group_id)
ALTER TABLE recording ADD CONSTRAINT rcrdngrcnstrctnsid FOREIGN KEY (recinstructions_id) REFERENCES recinstructions (recinstructions_id)
ALTER TABLE recording ADD CONSTRAINT rcrdingrccommentid FOREIGN KEY (reccomment_id) REFERENCES reccomment (reccomment_id)
ALTER TABLE recording ADD CONSTRAINT recordingsectionid FOREIGN KEY (section_id) REFERENCES section (section_id)
ALTER TABLE recgroup ADD CONSTRAINT rcgrouprecordingid FOREIGN KEY (recording_id) REFERENCES recording (recording_id)
ALTER TABLE section ADD CONSTRAINT section_script_id FOREIGN KEY (script_id) REFERENCES script (script_id)
ALTER TABLE message ADD CONSTRAINT message_reply_of FOREIGN KEY (reply_of) REFERENCES message (message_id)
ALTER TABLE message ADD CONSTRAINT message_to_login FOREIGN KEY (to_login) REFERENCES account (login)
ALTER TABLE message ADD CONSTRAINT message_from_login FOREIGN KEY (from_login) REFERENCES account (login)
ALTER TABLE recording_file ADD CONSTRAINT rcrdingfilesssonid FOREIGN KEY (session_id) REFERENCES session (session_id)
ALTER TABLE recording_file ADD CONSTRAINT rcrdingfilesgnalid FOREIGN KEY (signal_id) REFERENCES signal (signal_id)
ALTER TABLE recording_file ADD CONSTRAINT rcrdngfilercrdngid FOREIGN KEY (recording_id) REFERENCES recording (recording_id)
ALTER TABLE recording_track ADD CONSTRAINT rcrdngtrcrcrdngfld FOREIGN KEY (recording_file_id) REFERENCES recording_file (recording_file_id)
ALTER TABLE public.metadata ADD CONSTRAINT metadata_script_id FOREIGN KEY (script_id) REFERENCES script (script_id)
ALTER TABLE public.property ADD CONSTRAINT propertymetadataid FOREIGN KEY (metadata_id) REFERENCES public.metadata (metadata_id)
ALTER TABLE technician ADD CONSTRAINT technicianpersonid FOREIGN KEY (person_id) REFERENCES person (person_id)
ALTER TABLE public.localized_message ADD CONSTRAINT lclzdmslclzblmssgd FOREIGN KEY (localizable_message_id) REFERENCES public.localizable_message (localizable_message_id)
ALTER TABLE PROPERTYCONFIGURATION ADD CONSTRAINT PRPRTYCFRMCNFGRTNd FOREIGN KEY (FORMCONFIGURATION_id) REFERENCES FORMCONFIGURATION (id)
ALTER TABLE project_admin_account ADD CONSTRAINT prjctdmnccndmnccnt FOREIGN KEY (admin_account) REFERENCES account (login)
ALTER TABLE project_admin_account ADD CONSTRAINT prjctdmnccuntprjct FOREIGN KEY (project) REFERENCES public.project (name)
ALTER TABLE project_account ADD CONSTRAINT prjctaccountprject FOREIGN KEY (project) REFERENCES public.project (name)
ALTER TABLE project_account ADD CONSTRAINT prjectaccountccunt FOREIGN KEY (account) REFERENCES account (login)
ALTER TABLE belongs_to ADD CONSTRAINT blngstorgnsationid FOREIGN KEY (organisation_id) REFERENCES organisation (organisation_id)
ALTER TABLE belongs_to ADD CONSTRAINT belongstoperson_id FOREIGN KEY (person_id) REFERENCES person (person_id)
ALTER TABLE project_organisations ADD CONSTRAINT prjctrgnstonsprjct FOREIGN KEY (project) REFERENCES public.project (name)
ALTER TABLE project_organisations ADD CONSTRAINT prjctrgnstnsrgnstn FOREIGN KEY (organisation) REFERENCES organisation (organisation_id)
ALTER TABLE participates ADD CONSTRAINT prtcipatessssionid FOREIGN KEY (session_id) REFERENCES session (session_id)
ALTER TABLE participates ADD CONSTRAINT prticipatesspkerid FOREIGN KEY (speaker_id) REFERENCES person (person_id)
ALTER TABLE project_audio_device ADD CONSTRAINT prjctdodeviceprjct FOREIGN KEY (project) REFERENCES public.project (name)
ALTER TABLE project_audio_device ADD CONSTRAINT prjctddeviceddvcid FOREIGN KEY (audio_device_id) REFERENCES public.audio_device (audio_device_id)
ALTER TABLE project_dialect_region ADD CONSTRAINT prjctdlctrgonprjct FOREIGN KEY (project) REFERENCES public.project (name)
ALTER TABLE project_dialect_region ADD CONSTRAINT prjctdlctrgdlctrgn FOREIGN KEY (dialect_region) REFERENCES public.dialect_region (dialect_region_id)
ALTER TABLE project_scripts ADD CONSTRAINT prjectscriptsscrpt FOREIGN KEY (script) REFERENCES script (script_id)
ALTER TABLE project_scripts ADD CONSTRAINT prjctscriptsprject FOREIGN KEY (project) REFERENCES public.project (name)
ALTER TABLE recording_mediaitem ADD CONSTRAINT rcrdPrmpttmrcrdngd FOREIGN KEY (PromptItem_recording_id) REFERENCES recording (recording_id)
ALTER TABLE recording_mediaitem ADD CONSTRAINT rcrdngmdmdtmsmdtmd FOREIGN KEY (mediaitems_mediaitem_id) REFERENCES mediaitem (mediaitem_id)
ALTER TABLE mediaitem_recording ADD CONSTRAINT mdtmrcrdnMdtmmdtmd FOREIGN KEY (Mediaitem_mediaitem_id) REFERENCES mediaitem (mediaitem_id)
ALTER TABLE mediaitem_recording ADD CONSTRAINT mprmpttmsStrcrdngd FOREIGN KEY (promptItemsSet_recording_id) REFERENCES recording (recording_id)
ALTER TABLE annotates ADD CONSTRAINT nnotatesrcordingid FOREIGN KEY (recording_id) REFERENCES recording_file (recording_file_id)
ALTER TABLE annotates ADD CONSTRAINT nntatesnnotationid FOREIGN KEY (annotation_id) REFERENCES annotation (annotation_id)
ALTER TABLE supervises ADD CONSTRAINT sprvisesrcordingid FOREIGN KEY (recording_id) REFERENCES recording_file (recording_file_id)
ALTER TABLE supervises ADD CONSTRAINT sprvisestchncianid FOREIGN KEY (technician_id) REFERENCES person (person_id)
ALTER TABLE distribution_recording_files ADD CONSTRAINT dstrbtnrcrddsrbtnd FOREIGN KEY (disribution_id) REFERENCES distribution (distribution_id)
ALTER TABLE distribution_recording_files ADD CONSTRAINT dstrbtnrcrcrdngfld FOREIGN KEY (recording_file_id) REFERENCES recording_file (recording_file_id)
